![GitHub release (latest by date)](https://img.shields.io/github/v/release/Serapieum-of-alex/serapeum_utils)
[![Python Versions](https://img.shields.io/pypi/pyversions/HAPI-Nile.png)](https://img.shields.io/pypi/pyversions/HAPI-Nile)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/Serapieum-of-alex/Hapi.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Serapieum-of-alex/Hapi/context:python)

Current build status
====================


<table><tr><td>All platforms:</td>
    <td>
      <a href="https://dev.azure.com/conda-forge/feedstock-builds/_build/latest?definitionId=12419&branchName=master">
        <img src="https://dev.azure.com/conda-forge/feedstock-builds/_apis/build/status/hapi-feedstock?branchName=master">
      </a>
    </td>
  </tr>
</table>

![GitHub last commit](https://img.shields.io/github/last-commit/Serapieum-of-alex/serapeum_utils)
![GitHub forks](https://img.shields.io/github/forks/Serapieum-of-alex/serapeum_utils?style=social)
![GitHub Repo stars](https://img.shields.io/github/stars/Serapieum-of-alex/serapeum_utils?style=social)



[![Github all releases](https://img.shields.io/github/downloads/Naereen/StrapDown.js/total.svg)](https://GitHub.com/Naereen/StrapDown.js/releases/)


Current release info
====================

| Name | Downloads                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | Version | Platforms |
| --- | | --- | --- |
| [![Conda Recipe](https://img.shields.io/badge/recipe-serapeum_utils-green.svg)](https://anaconda.org/conda-forge/serapeum_utils) | [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/serapeum_utils.svg)](https://anaconda.org/conda-forge/serapeum_utils) [![Downloads](https://pepy.tech/badge/serapeum_utils-nile)](https://pepy.tech/project/serapeum_utils-nile) [![Downloads](https://pepy.tech/badge/serapeum_utils-nile/month)](https://pepy.tech/project/serapeum_utils-nile)  [![Downloads](https://pepy.tech/badge/serapeum_utils-nile/week)](https://pepy.tech/project/serapeum_utils-nile)  ![PyPI - Downloads](https://img.shields.io/pypi/dd/serapeum_utils-nile?color=blue&style=flat-square) ![GitHub all releases](https://img.shields.io/github/downloads/Serapieum-of-alex/serapeum_utils/total) ![GitHub release (latest by date)](https://img.shields.io/github/downloads/Serapieum-of-alex/serapeum_utils/1.2.3/total) | [![Conda Version](https://img.shields.io/conda/vn/conda-forge/serapeum_utils.svg)](https://anaconda.org/conda-forge/serapeum_utils) [![PyPI version](https://badge.fury.io/py/serapeum_utils-Nile.svg)](https://badge.fury.io/py/serapeum_utils-Nile) [![Anaconda-Server Badge](https://anaconda.org/conda-forge/serapeum_utils/badges/version.svg)](https://anaconda.org/conda-forge/serapeum_utils) | [![Conda Platforms](https://img.shields.io/conda/pn/conda-forge/serapeum_utils.svg)](https://anaconda.org/conda-forge/serapeum_utils) [![Join the chat at https://gitter.im/serapeum_utils-Nile/serapeum_utils](https://badges.gitter.im/serapeum_utils-Nile/serapeum_utils.svg)](https://gitter.im/serapeum_utils-Nile/serapeum_utils?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge) |





serapeum_utils - utility library for Python
=====================================================================
**serapeum_utils** is an open-source Python utility package


serapeum_utils

Main Features
-------------
  -


Installing serapeum_utils
===============

Installing `serapeum_utils` from the `conda-forge` channel can be achieved by:

```
conda install -c conda-forge serapeum_utils
```

It is possible to list all of the versions of `serapeum_utils` available on your platform with:

```
conda search serapeum_utils --channel conda-forge
```

## Install from Github
to install the last development to time you can install the library from github
```
pip install git+https://github.com/Serapieum-of-alex/serapeum_utils
```

## pip
to install the last release you can easly use pip
```
pip install serapeum_utils==0.1.1
```

Quick start
===========

```
  >>> import serapeum_utils
```
